@@ -16,8 +16,7 @@ doStat <- function(x, Group = NULL){
   myCV <- getCV(x, Group = Group)
   myFC <- getFC(x, Group = Group)
   myP <- getP(x, Group = Group)
-  myOPLSDA <- getOPLSDA(x, Group = Group)
-  myStat <- cbind(maxSample, myCV, myFC, myP, myOPLSDA)
+  myStat <- cbind(maxSample, myCV, myFC, myP)
   cat("\nStatistical analysis done. \n")
   rownames(myStat) <- colnames(x)
   return(myStat)
