@@ -1,17 +1,22 @@
-#' @title accurate ion mass
-#' @description calculate accurate ion mass
+#' @title Calculate accurate mass-to-charge ratio
+#' @description Calculate accurate mass-to-charge ratio (m/z)
 #' @author Yonghui Dong
 #' @param m chemical formula of an ion, case insensitive
 #' @param z charge
+#' @param caseSensitive if case sensitive is `FALSE` (default), the elements are seperated by numbers.
+#' for instance, Carbon dioxyde can be written as 'c1o2' or any combination of the two elements in lower or
+#' upper cases. However, the number of elements should be clearly stated in the chemical formula. if case
+#' sensitive is `TRUE`, the elements are seperated by upper case letters. For instance, Carbon dioxyde must
+#' be written as 'C1O2' or `CO2`. You don't meed to write the number of the element if it is 1.
 #' @importFrom crayon cyan bgMagenta
 #' @export
 #' @examples
-#'  mz('C7H7O4', z = 1)
-#'  mz('C10H6Cl1', z = -1)
-#'  mz('C7h7O4', z = 1) # case insensitive
-#'  mz(c('C7H7O4', 'c1'), z = -1) # vector input
+#'  mz('C7h7o1', z = 1)
+#'  mz('C7H7O', z = 1, caseSensitive = TRUE)
+#'  mz(c('C7H7O4', 'C'), z = -1, caseSensitive = TRUE) # vector input
+#'  mz(c('c7h7O4', 'c1'), z = -1)
 
-mz <- function(m, z) {
+mz <- function(m, z, caseSensitive = FALSE) {
   options(digits = 12)
 
   #(1) check input
@@ -30,12 +35,16 @@ mz <- function(m, z) {
   #(3) allow the function to a vector of input
   if (length(m) > 1) {
     m = as.list(m)
-    acc_mz <- sapply(m, mz, z = z)
+    acc_mz <- sapply(m, mz, z = z, caseSensitive = caseSensitive)
     names(acc_mz) <- m
     return(acc_mz)
   }
 
   #(4) main function
+  ## If caseSensitive == T, split the mass formula based on upper case letters and add missing 1.
+  if(isTRUE(caseSensitive)) {
+    m <- gsub("([A-Z][a-z]?)(?!\\d)","\\11", m, perl = TRUE)
+  }
   ## format input
   ## split the mass formula
   v1 <- strsplit(m, "(?<=[A-Za-z])(?=[0-9])|(?<=[0-9])(?=[A-Za-z])", perl = TRUE)[[1]]
@@ -64,4 +73,12 @@ mz <- function(m, z) {
   }
   else
     message('Wrong chemical formula. Are numbers of some elements missing?')
+
+  #(3) allow the function to a vector of input
+  if (length(m) > 1) {
+    m = as.list(m)
+    acc_mz <- sapply(m, mz, z = z)
+    names(acc_mz) <- m
+    return(acc_mz)
+  }
 }
